==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/crafting/recipe/WaterBottleMatchingRecipe.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.crafting.recipe;

import com.google.gson.JsonObject;
import net.minecraft.class_1715;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1844;
import net.minecraft.class_1847;
import net.minecraft.class_1856;
import net.minecraft.class_1865;
import net.minecraft.class_1869;
import net.minecraft.class_1937;
import net.minecraft.class_2371;
import net.minecraft.class_2540;
import net.minecraft.class_2960;
import org.jetbrains.annotations.NotNull;

import vazkii.botania.common.crafting.RecipeSerializerBase;

public class WaterBottleMatchingRecipe extends class_1869 {
	public static final class_1865<WaterBottleMatchingRecipe> SERIALIZER = new Serializer();

	public WaterBottleMatchingRecipe(class_2960 id, String group, int width, int height, class_2371<class_1856> recipeItems, class_1799 result) {
		super(id, group, width, height, class_2371.method_10212(class_1856.field_9017, recipeItems.stream().map(i -> {
			if (i.method_8093(new class_1799(class_1802.field_8574))) {
				return class_1856.method_8101(class_1844.method_8061(new class_1799(class_1802.field_8574), class_1847.field_8991));
			}
			return i;
		}).toArray(class_1856[]::new)), result);
	}

	public WaterBottleMatchingRecipe(class_1869 recipe) {
		this(recipe.method_8114(), recipe.method_8112(), recipe.method_8150(), recipe.method_8158(), recipe.method_8117(), recipe.method_8110());
	}

	@Override
	public boolean method_17728(@NotNull class_1715 craftingContainer, @NotNull class_1937 level) {
		if (!super.method_17728(craftingContainer, level)) {
			return false;
		}
		for (int i = 0; i < craftingContainer.method_5439(); i++) {
			var item = craftingContainer.method_5438(i);
			if (item.method_31574(class_1802.field_8574) && !(class_1844.method_8063(item) == class_1847.field_8991)) {
				return false;
			}
		}
		return true;
	}

	@Override
	public class_1865<?> method_8119() {
		return SERIALIZER;
	}

	private static class Serializer extends RecipeSerializerBase<WaterBottleMatchingRecipe> {
		@Override
		public WaterBottleMatchingRecipe method_8121(@NotNull class_2960 recipeId, @NotNull JsonObject json) {
			return new WaterBottleMatchingRecipe(field_9035.method_8121(recipeId, json));
		}

		@Override
		public WaterBottleMatchingRecipe method_8122(@NotNull class_2960 recipeId, @NotNull class_2540 buffer) {
			return new WaterBottleMatchingRecipe(field_9035.method_8122(recipeId, buffer));
		}

		@Override
		public void toNetwork(@NotNull class_2540 buffer, @NotNull WaterBottleMatchingRecipe recipe) {
			field_9035.method_8124(buffer, recipe);
		}
	}
}

==> Botania-1.20.1-451-FABRIC-20251124.130120-29-sources.jar: vazkii/botania/common/crafting/recipe/WaterBottleMatchingRecipe.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.crafting.recipe;

import com.google.gson.JsonObject;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1844;
import net.minecraft.class_1847;
import net.minecraft.class_1856;
import net.minecraft.class_1865;
import net.minecraft.class_1869;
import net.minecraft.class_1937;
import net.minecraft.class_2371;
import net.minecraft.class_2540;
import net.minecraft.class_2960;
import net.minecraft.class_5455;
import net.minecraft.class_7710;
import net.minecraft.class_8566;
import org.jetbrains.annotations.NotNull;

public class WaterBottleMatchingRecipe extends class_1869 {
	public static final class_1865<WaterBottleMatchingRecipe> SERIALIZER = new Serializer();

	public WaterBottleMatchingRecipe(class_2960 id, String group, class_7710 category, int width, int height, class_2371<class_1856> recipeItems, class_1799 result) {
		super(id, group, category, width, height, class_2371.method_10212(class_1856.field_9017, recipeItems.stream().map(i -> {
			if (i.method_8093(new class_1799(class_1802.field_8574))) {
				return class_1856.method_8101(class_1844.method_8061(new class_1799(class_1802.field_8574), class_1847.field_8991));
			}
			return i;
		}).toArray(class_1856[]::new)), result);
	}

	public WaterBottleMatchingRecipe(class_1869 recipe) {
		this(recipe.method_8114(), recipe.method_8112(), recipe.method_45441(), recipe.method_8150(), recipe.method_8158(),
				recipe.method_8117(),
				// XXX: Hacky, but compose should always be a vanilla shaped recipe which doesn't do anything with the
				// RegistryAccess
				recipe.method_8110(class_5455.field_40585));
	}

	@Override
	public boolean method_17728(@NotNull class_8566 craftingContainer, @NotNull class_1937 level) {
		if (!super.method_17728(craftingContainer, level)) {
			return false;
		}
		for (int i = 0; i < craftingContainer.method_5439(); i++) {
			var item = craftingContainer.method_5438(i);
			if (item.method_31574(class_1802.field_8574) && !(class_1844.method_8063(item) == class_1847.field_8991)) {
				return false;
			}
		}
		return true;
	}

	@Override
	public class_1865<?> method_8119() {
		return SERIALIZER;
	}

	private static class Serializer implements class_1865<WaterBottleMatchingRecipe> {
		@Override
		public WaterBottleMatchingRecipe method_8121(@NotNull class_2960 recipeId, @NotNull JsonObject json) {
			return new WaterBottleMatchingRecipe(field_9035.method_8121(recipeId, json));
		}

		@Override
		public WaterBottleMatchingRecipe method_8122(@NotNull class_2960 recipeId, @NotNull class_2540 buffer) {
			return new WaterBottleMatchingRecipe(field_9035.method_8122(recipeId, buffer));
		}

		@Override
		public void toNetwork(@NotNull class_2540 buffer, @NotNull WaterBottleMatchingRecipe recipe) {
			field_9035.method_8124(buffer, recipe);
		}
	}
}
